Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterBinaryNetworkEndpointProxyServer(s grpc.ServiceRegistrar, srv BinaryNetworkEndpointProxyServer)
- func RegisterEndpoint2ProxyServer(s grpc.ServiceRegistrar, srv Endpoint2ProxyServer)
- type BinaryMessageWithSender
- func (*BinaryMessageWithSender) Descriptor() ([]byte, []int)deprecated
- func (x *BinaryMessageWithSender) GetMsg() []byte
- func (x *BinaryMessageWithSender) GetSender() uint32
- func (*BinaryMessageWithSender) ProtoMessage()
- func (x *BinaryMessageWithSender) ProtoReflect() protoreflect.Message
- func (x *BinaryMessageWithSender) Reset()
- func (x *BinaryMessageWithSender) String() string
- type BinaryNetworkClientRequest
- func (*BinaryNetworkClientRequest) Descriptor() ([]byte, []int)deprecated
- func (x *BinaryNetworkClientRequest) GetBroadcast() []byte
- func (x *BinaryNetworkClientRequest) GetMessage() isBinaryNetworkClientRequest_Message
- func (x *BinaryNetworkClientRequest) GetNewEndpoint() *NewEndpointRequest
- func (x *BinaryNetworkClientRequest) GetSendTo() *SendToRequest
- func (*BinaryNetworkClientRequest) ProtoMessage()
- func (x *BinaryNetworkClientRequest) ProtoReflect() protoreflect.Message
- func (x *BinaryNetworkClientRequest) Reset()
- func (x *BinaryNetworkClientRequest) String() string
- type BinaryNetworkClientRequest_Broadcast
- type BinaryNetworkClientRequest_NewEndpoint
- type BinaryNetworkClientRequest_SendTo
- type BinaryNetworkEndpointLimits
- func (*BinaryNetworkEndpointLimits) Descriptor() ([]byte, []int)deprecated
- func (x *BinaryNetworkEndpointLimits) GetBytesCapacityPerOracle() int32
- func (x *BinaryNetworkEndpointLimits) GetBytesRatePerOracle() float64
- func (x *BinaryNetworkEndpointLimits) GetMaxMessageLength() int32
- func (x *BinaryNetworkEndpointLimits) GetMessagesCapacityPerOracle() int32
- func (x *BinaryNetworkEndpointLimits) GetMessagesRatePerOracle() float64
- func (*BinaryNetworkEndpointLimits) ProtoMessage()
- func (x *BinaryNetworkEndpointLimits) ProtoReflect() protoreflect.Message
- func (x *BinaryNetworkEndpointLimits) Reset()
- func (x *BinaryNetworkEndpointLimits) String() string
- type BinaryNetworkEndpointProxyClient
- type BinaryNetworkEndpointProxyServer
- type BinaryNetworkEndpointProxy_ConnectClient
- type BinaryNetworkEndpointProxy_ConnectServer
- type BootstrapperLocator
- func (*BootstrapperLocator) Descriptor() ([]byte, []int)deprecated
- func (x *BootstrapperLocator) GetAddrs() []string
- func (x *BootstrapperLocator) GetPeerId() string
- func (*BootstrapperLocator) ProtoMessage()
- func (x *BootstrapperLocator) ProtoReflect() protoreflect.Message
- func (x *BootstrapperLocator) Reset()
- func (x *BootstrapperLocator) String() string
- type ClosableBinaryNetworkEndpoint2Factory
- type ClosableBinaryNetworkEndpointFactory
- type Endpoint2ClientRequest
- func (*Endpoint2ClientRequest) Descriptor() ([]byte, []int)deprecated
- func (x *Endpoint2ClientRequest) GetBroadcast() *Endpoint2Send
- func (x *Endpoint2ClientRequest) GetMessage() isEndpoint2ClientRequest_Message
- func (x *Endpoint2ClientRequest) GetNewEndpoint() *NewEndpoint2Request
- func (x *Endpoint2ClientRequest) GetSendTo() *Endpoint2Send
- func (*Endpoint2ClientRequest) ProtoMessage()
- func (x *Endpoint2ClientRequest) ProtoReflect() protoreflect.Message
- func (x *Endpoint2ClientRequest) Reset()
- func (x *Endpoint2ClientRequest) String() string
- type Endpoint2ClientRequest_Broadcast
- type Endpoint2ClientRequest_NewEndpoint
- type Endpoint2ClientRequest_SendTo
- type Endpoint2Config
- func (*Endpoint2Config) Descriptor() ([]byte, []int)deprecated
- func (x *Endpoint2Config) GetLimits() *BinaryNetworkEndpointLimits
- func (x *Endpoint2Config) GetOverrideIncomingMessageBufferSize() int32
- func (x *Endpoint2Config) GetOverrideOutgoingMessageBufferSize() int32
- func (*Endpoint2Config) ProtoMessage()
- func (x *Endpoint2Config) ProtoReflect() protoreflect.Message
- func (x *Endpoint2Config) Reset()
- func (x *Endpoint2Config) String() string
- type Endpoint2ProxyClient
- type Endpoint2ProxyServer
- type Endpoint2Proxy_ConnectClient
- type Endpoint2Proxy_ConnectServer
- type Endpoint2Send
- func (*Endpoint2Send) Descriptor() ([]byte, []int)deprecated
- func (x *Endpoint2Send) GetMsg() *OutboundMessage2
- func (x *Endpoint2Send) GetToOracleId() uint32
- func (*Endpoint2Send) ProtoMessage()
- func (x *Endpoint2Send) ProtoReflect() protoreflect.Message
- func (x *Endpoint2Send) Reset()
- func (x *Endpoint2Send) String() string
- type Endpoint2ServerMessage
- func (*Endpoint2ServerMessage) Descriptor() ([]byte, []int)deprecated
- func (x *Endpoint2ServerMessage) GetKind() isEndpoint2ServerMessage_Kind
- func (x *Endpoint2ServerMessage) GetPayload() []byte
- func (x *Endpoint2ServerMessage) GetPlain() *InboundPlain2
- func (x *Endpoint2ServerMessage) GetPriority() uint32
- func (x *Endpoint2ServerMessage) GetRequest() *InboundRequest2
- func (x *Endpoint2ServerMessage) GetResponse() *InboundResponse2
- func (x *Endpoint2ServerMessage) GetSender() uint32
- func (*Endpoint2ServerMessage) ProtoMessage()
- func (x *Endpoint2ServerMessage) ProtoReflect() protoreflect.Message
- func (x *Endpoint2ServerMessage) Reset()
- func (x *Endpoint2ServerMessage) String() string
- type Endpoint2ServerMessage_Plain
- type Endpoint2ServerMessage_Request
- type Endpoint2ServerMessage_Response
- type InboundPlain2
- type InboundRequest2
- type InboundResponse2
- type NewEndpoint2Request
- func (*NewEndpoint2Request) Descriptor() ([]byte, []int)deprecated
- func (x *NewEndpoint2Request) GetConfigDigest() []byte
- func (x *NewEndpoint2Request) GetDefaultPriorityConfig() *Endpoint2Config
- func (x *NewEndpoint2Request) GetLowPriorityConfig() *Endpoint2Config
- func (x *NewEndpoint2Request) GetPeerIds() []string
- func (x *NewEndpoint2Request) GetV2Bootstrappers() []*BootstrapperLocator
- func (*NewEndpoint2Request) ProtoMessage()
- func (x *NewEndpoint2Request) ProtoReflect() protoreflect.Message
- func (x *NewEndpoint2Request) Reset()
- func (x *NewEndpoint2Request) String() string
- type NewEndpointRequest
- func (*NewEndpointRequest) Descriptor() ([]byte, []int)deprecated
- func (x *NewEndpointRequest) GetConfigDigest() []byte
- func (x *NewEndpointRequest) GetFailureThreshold() int32
- func (x *NewEndpointRequest) GetLimits() *BinaryNetworkEndpointLimits
- func (x *NewEndpointRequest) GetPeerIds() []string
- func (x *NewEndpointRequest) GetV2Bootstrappers() []*BootstrapperLocator
- func (*NewEndpointRequest) ProtoMessage()
- func (x *NewEndpointRequest) ProtoReflect() protoreflect.Message
- func (x *NewEndpointRequest) Reset()
- func (x *NewEndpointRequest) String() string
- type OutboundMessage2
- func (*OutboundMessage2) Descriptor() ([]byte, []int)deprecated
- func (x *OutboundMessage2) GetKind() isOutboundMessage2_Kind
- func (x *OutboundMessage2) GetPayload() []byte
- func (x *OutboundMessage2) GetPlain() *OutboundPlain2
- func (x *OutboundMessage2) GetPriority() uint32
- func (x *OutboundMessage2) GetRequest() *OutboundRequest2
- func (x *OutboundMessage2) GetResponse() *OutboundResponse2
- func (*OutboundMessage2) ProtoMessage()
- func (x *OutboundMessage2) ProtoReflect() protoreflect.Message
- func (x *OutboundMessage2) Reset()
- func (x *OutboundMessage2) String() string
- type OutboundMessage2_Plain
- type OutboundMessage2_Request
- type OutboundMessage2_Response
- type OutboundPlain2
- type OutboundRequest2
- func (*OutboundRequest2) Descriptor() ([]byte, []int)deprecated
- func (x *OutboundRequest2) GetPolicyExpiryUnixMs() int64
- func (x *OutboundRequest2) GetPolicyMaxSize() int64
- func (*OutboundRequest2) ProtoMessage()
- func (x *OutboundRequest2) ProtoReflect() protoreflect.Message
- func (x *OutboundRequest2) Reset()
- func (x *OutboundRequest2) String() string
- type OutboundResponse2
- type ProxyEndpoint
- type ProxyEndpoint2Factory
- type ProxyEndpointFactory
- type SendToRequest
- func (*SendToRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SendToRequest) GetPayload() []byte
- func (x *SendToRequest) GetToOracleId() uint32
- func (*SendToRequest) ProtoMessage()
- func (x *SendToRequest) ProtoReflect() protoreflect.Message
- func (x *SendToRequest) Reset()
- func (x *SendToRequest) String() string
- type UnimplementedBinaryNetworkEndpointProxyServer
- type UnimplementedEndpoint2ProxyServer
- type UnsafeBinaryNetworkEndpointProxyServer
- type UnsafeEndpoint2ProxyServer
Constants ¶
const (
BinaryNetworkEndpointProxy_Connect_FullMethodName = "/shared.BinaryNetworkEndpointProxy/Connect"
)
const (
Endpoint2Proxy_Connect_FullMethodName = "/shared.Endpoint2Proxy/Connect"
)
Variables ¶
var BinaryNetworkEndpointProxy_ServiceDesc = grpc.ServiceDesc{ ServiceName: "shared.BinaryNetworkEndpointProxy", HandlerType: (*BinaryNetworkEndpointProxyServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "Connect", Handler: _BinaryNetworkEndpointProxy_Connect_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "proxy.proto", }
BinaryNetworkEndpointProxy_ServiceDesc is the grpc.ServiceDesc for BinaryNetworkEndpointProxy service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var Endpoint2Proxy_ServiceDesc = grpc.ServiceDesc{ ServiceName: "shared.Endpoint2Proxy", HandlerType: (*Endpoint2ProxyServer)(nil), Methods: []grpc.MethodDesc{}, Streams: []grpc.StreamDesc{ { StreamName: "Connect", Handler: _Endpoint2Proxy_Connect_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "proxy.proto", }
Endpoint2Proxy_ServiceDesc is the grpc.ServiceDesc for Endpoint2Proxy service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proxy_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBinaryNetworkEndpointProxyServer ¶
func RegisterBinaryNetworkEndpointProxyServer(s grpc.ServiceRegistrar, srv BinaryNetworkEndpointProxyServer)
func RegisterEndpoint2ProxyServer ¶
func RegisterEndpoint2ProxyServer(s grpc.ServiceRegistrar, srv Endpoint2ProxyServer)
Types ¶
type BinaryMessageWithSender ¶
type BinaryMessageWithSender struct {
Msg []byte `protobuf:"bytes,1,opt,name=msg,proto3" json:"msg,omitempty"`
Sender uint32 `protobuf:"varint,2,opt,name=sender,proto3" json:"sender,omitempty"`
// contains filtered or unexported fields
}
func (*BinaryMessageWithSender) Descriptor
deprecated
func (*BinaryMessageWithSender) Descriptor() ([]byte, []int)
Deprecated: Use BinaryMessageWithSender.ProtoReflect.Descriptor instead.
func (*BinaryMessageWithSender) GetMsg ¶
func (x *BinaryMessageWithSender) GetMsg() []byte
func (*BinaryMessageWithSender) GetSender ¶
func (x *BinaryMessageWithSender) GetSender() uint32
func (*BinaryMessageWithSender) ProtoMessage ¶
func (*BinaryMessageWithSender) ProtoMessage()
func (*BinaryMessageWithSender) ProtoReflect ¶
func (x *BinaryMessageWithSender) ProtoReflect() protoreflect.Message
func (*BinaryMessageWithSender) Reset ¶
func (x *BinaryMessageWithSender) Reset()
func (*BinaryMessageWithSender) String ¶
func (x *BinaryMessageWithSender) String() string
type BinaryNetworkClientRequest ¶
type BinaryNetworkClientRequest struct {
// Types that are valid to be assigned to Message:
//
// *BinaryNetworkClientRequest_NewEndpoint
// *BinaryNetworkClientRequest_SendTo
// *BinaryNetworkClientRequest_Broadcast
Message isBinaryNetworkClientRequest_Message `protobuf_oneof:"message"`
// contains filtered or unexported fields
}
func (*BinaryNetworkClientRequest) Descriptor
deprecated
func (*BinaryNetworkClientRequest) Descriptor() ([]byte, []int)
Deprecated: Use BinaryNetworkClientRequest.ProtoReflect.Descriptor instead.
func (*BinaryNetworkClientRequest) GetBroadcast ¶
func (x *BinaryNetworkClientRequest) GetBroadcast() []byte
func (*BinaryNetworkClientRequest) GetMessage ¶
func (x *BinaryNetworkClientRequest) GetMessage() isBinaryNetworkClientRequest_Message
func (*BinaryNetworkClientRequest) GetNewEndpoint ¶
func (x *BinaryNetworkClientRequest) GetNewEndpoint() *NewEndpointRequest
func (*BinaryNetworkClientRequest) GetSendTo ¶
func (x *BinaryNetworkClientRequest) GetSendTo() *SendToRequest
func (*BinaryNetworkClientRequest) ProtoMessage ¶
func (*BinaryNetworkClientRequest) ProtoMessage()
func (*BinaryNetworkClientRequest) ProtoReflect ¶
func (x *BinaryNetworkClientRequest) ProtoReflect() protoreflect.Message
func (*BinaryNetworkClientRequest) Reset ¶
func (x *BinaryNetworkClientRequest) Reset()
func (*BinaryNetworkClientRequest) String ¶
func (x *BinaryNetworkClientRequest) String() string
type BinaryNetworkClientRequest_Broadcast ¶
type BinaryNetworkClientRequest_Broadcast struct {
Broadcast []byte `protobuf:"bytes,3,opt,name=broadcast,proto3,oneof"`
}
type BinaryNetworkClientRequest_NewEndpoint ¶
type BinaryNetworkClientRequest_NewEndpoint struct {
NewEndpoint *NewEndpointRequest `protobuf:"bytes,1,opt,name=newEndpoint,proto3,oneof"`
}
type BinaryNetworkClientRequest_SendTo ¶
type BinaryNetworkClientRequest_SendTo struct {
SendTo *SendToRequest `protobuf:"bytes,2,opt,name=sendTo,proto3,oneof"`
}
type BinaryNetworkEndpointLimits ¶
type BinaryNetworkEndpointLimits struct {
MaxMessageLength int32 `protobuf:"varint,1,opt,name=max_message_length,json=maxMessageLength,proto3" json:"max_message_length,omitempty"`
MessagesRatePerOracle float64 `` /* 130-byte string literal not displayed */
MessagesCapacityPerOracle int32 `` /* 141-byte string literal not displayed */
BytesRatePerOracle float64 `protobuf:"fixed64,4,opt,name=bytes_rate_per_oracle,json=bytesRatePerOracle,proto3" json:"bytes_rate_per_oracle,omitempty"`
BytesCapacityPerOracle int32 `` /* 132-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*BinaryNetworkEndpointLimits) Descriptor
deprecated
func (*BinaryNetworkEndpointLimits) Descriptor() ([]byte, []int)
Deprecated: Use BinaryNetworkEndpointLimits.ProtoReflect.Descriptor instead.
func (*BinaryNetworkEndpointLimits) GetBytesCapacityPerOracle ¶
func (x *BinaryNetworkEndpointLimits) GetBytesCapacityPerOracle() int32
func (*BinaryNetworkEndpointLimits) GetBytesRatePerOracle ¶
func (x *BinaryNetworkEndpointLimits) GetBytesRatePerOracle() float64
func (*BinaryNetworkEndpointLimits) GetMaxMessageLength ¶
func (x *BinaryNetworkEndpointLimits) GetMaxMessageLength() int32
func (*BinaryNetworkEndpointLimits) GetMessagesCapacityPerOracle ¶
func (x *BinaryNetworkEndpointLimits) GetMessagesCapacityPerOracle() int32
func (*BinaryNetworkEndpointLimits) GetMessagesRatePerOracle ¶
func (x *BinaryNetworkEndpointLimits) GetMessagesRatePerOracle() float64
func (*BinaryNetworkEndpointLimits) ProtoMessage ¶
func (*BinaryNetworkEndpointLimits) ProtoMessage()
func (*BinaryNetworkEndpointLimits) ProtoReflect ¶
func (x *BinaryNetworkEndpointLimits) ProtoReflect() protoreflect.Message
func (*BinaryNetworkEndpointLimits) Reset ¶
func (x *BinaryNetworkEndpointLimits) Reset()
func (*BinaryNetworkEndpointLimits) String ¶
func (x *BinaryNetworkEndpointLimits) String() string
type BinaryNetworkEndpointProxyClient ¶
type BinaryNetworkEndpointProxyClient interface {
Connect(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[BinaryNetworkClientRequest, BinaryMessageWithSender], error)
}
BinaryNetworkEndpointProxyClient is the client API for BinaryNetworkEndpointProxy service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewBinaryNetworkEndpointProxyClient ¶
func NewBinaryNetworkEndpointProxyClient(cc grpc.ClientConnInterface) BinaryNetworkEndpointProxyClient
type BinaryNetworkEndpointProxyServer ¶
type BinaryNetworkEndpointProxyServer interface {
Connect(grpc.BidiStreamingServer[BinaryNetworkClientRequest, BinaryMessageWithSender]) error
// contains filtered or unexported methods
}
BinaryNetworkEndpointProxyServer is the server API for BinaryNetworkEndpointProxy service. All implementations must embed UnimplementedBinaryNetworkEndpointProxyServer for forward compatibility.
type BinaryNetworkEndpointProxy_ConnectClient ¶
type BinaryNetworkEndpointProxy_ConnectClient = grpc.BidiStreamingClient[BinaryNetworkClientRequest, BinaryMessageWithSender]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type BinaryNetworkEndpointProxy_ConnectServer ¶
type BinaryNetworkEndpointProxy_ConnectServer = grpc.BidiStreamingServer[BinaryNetworkClientRequest, BinaryMessageWithSender]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type BootstrapperLocator ¶
type BootstrapperLocator struct {
PeerId string `protobuf:"bytes,1,opt,name=peer_id,json=peerId,proto3" json:"peer_id,omitempty"`
Addrs []string `protobuf:"bytes,2,rep,name=addrs,proto3" json:"addrs,omitempty"`
// contains filtered or unexported fields
}
func (*BootstrapperLocator) Descriptor
deprecated
func (*BootstrapperLocator) Descriptor() ([]byte, []int)
Deprecated: Use BootstrapperLocator.ProtoReflect.Descriptor instead.
func (*BootstrapperLocator) GetAddrs ¶
func (x *BootstrapperLocator) GetAddrs() []string
func (*BootstrapperLocator) GetPeerId ¶
func (x *BootstrapperLocator) GetPeerId() string
func (*BootstrapperLocator) ProtoMessage ¶
func (*BootstrapperLocator) ProtoMessage()
func (*BootstrapperLocator) ProtoReflect ¶
func (x *BootstrapperLocator) ProtoReflect() protoreflect.Message
func (*BootstrapperLocator) Reset ¶
func (x *BootstrapperLocator) Reset()
func (*BootstrapperLocator) String ¶
func (x *BootstrapperLocator) String() string
type ClosableBinaryNetworkEndpoint2Factory ¶
type ClosableBinaryNetworkEndpoint2Factory interface {
ocr2types.BinaryNetworkEndpoint2Factory
io.Closer
}
ClosableBinaryNetworkEndpoint2Factory is a BinaryNetworkEndpoint2Factory whose underlying connection can be released.
func NewProxyEndpoint2Factory ¶
func NewProxyEndpoint2Factory(peerID, proxyAddr string) (ClosableBinaryNetworkEndpoint2Factory, error)
NewProxyEndpoint2Factory dials the proxy at proxyAddr and returns a factory that creates remote-backed OCR3.1 endpoints.
type ClosableBinaryNetworkEndpointFactory ¶
type ClosableBinaryNetworkEndpointFactory interface {
types.BinaryNetworkEndpointFactory
io.Closer
}
func NewProxyEndpointFactory ¶
func NewProxyEndpointFactory(peerId, proxyAddr string) (ClosableBinaryNetworkEndpointFactory, error)
type Endpoint2ClientRequest ¶
type Endpoint2ClientRequest struct {
// Types that are valid to be assigned to Message:
//
// *Endpoint2ClientRequest_NewEndpoint
// *Endpoint2ClientRequest_SendTo
// *Endpoint2ClientRequest_Broadcast
Message isEndpoint2ClientRequest_Message `protobuf_oneof:"message"`
// contains filtered or unexported fields
}
func (*Endpoint2ClientRequest) Descriptor
deprecated
func (*Endpoint2ClientRequest) Descriptor() ([]byte, []int)
Deprecated: Use Endpoint2ClientRequest.ProtoReflect.Descriptor instead.
func (*Endpoint2ClientRequest) GetBroadcast ¶
func (x *Endpoint2ClientRequest) GetBroadcast() *Endpoint2Send
func (*Endpoint2ClientRequest) GetMessage ¶
func (x *Endpoint2ClientRequest) GetMessage() isEndpoint2ClientRequest_Message
func (*Endpoint2ClientRequest) GetNewEndpoint ¶
func (x *Endpoint2ClientRequest) GetNewEndpoint() *NewEndpoint2Request
func (*Endpoint2ClientRequest) GetSendTo ¶
func (x *Endpoint2ClientRequest) GetSendTo() *Endpoint2Send
func (*Endpoint2ClientRequest) ProtoMessage ¶
func (*Endpoint2ClientRequest) ProtoMessage()
func (*Endpoint2ClientRequest) ProtoReflect ¶
func (x *Endpoint2ClientRequest) ProtoReflect() protoreflect.Message
func (*Endpoint2ClientRequest) Reset ¶
func (x *Endpoint2ClientRequest) Reset()
func (*Endpoint2ClientRequest) String ¶
func (x *Endpoint2ClientRequest) String() string
type Endpoint2ClientRequest_Broadcast ¶
type Endpoint2ClientRequest_Broadcast struct {
Broadcast *Endpoint2Send `protobuf:"bytes,3,opt,name=broadcast,proto3,oneof"` // to_oracle_id is ignored
}
type Endpoint2ClientRequest_NewEndpoint ¶
type Endpoint2ClientRequest_NewEndpoint struct {
NewEndpoint *NewEndpoint2Request `protobuf:"bytes,1,opt,name=new_endpoint,json=newEndpoint,proto3,oneof"` // must be the first message
}
type Endpoint2ClientRequest_SendTo ¶
type Endpoint2ClientRequest_SendTo struct {
SendTo *Endpoint2Send `protobuf:"bytes,2,opt,name=send_to,json=sendTo,proto3,oneof"`
}
type Endpoint2Config ¶
type Endpoint2Config struct {
Limits *BinaryNetworkEndpointLimits `protobuf:"bytes,1,opt,name=limits,proto3" json:"limits,omitempty"`
OverrideIncomingMessageBufferSize *int32 `` /* 173-byte string literal not displayed */
OverrideOutgoingMessageBufferSize *int32 `` /* 173-byte string literal not displayed */
// contains filtered or unexported fields
}
Endpoint2Config mirrors ocr2types.BinaryNetworkEndpoint2Config.
func (*Endpoint2Config) Descriptor
deprecated
func (*Endpoint2Config) Descriptor() ([]byte, []int)
Deprecated: Use Endpoint2Config.ProtoReflect.Descriptor instead.
func (*Endpoint2Config) GetLimits ¶
func (x *Endpoint2Config) GetLimits() *BinaryNetworkEndpointLimits
func (*Endpoint2Config) GetOverrideIncomingMessageBufferSize ¶
func (x *Endpoint2Config) GetOverrideIncomingMessageBufferSize() int32
func (*Endpoint2Config) GetOverrideOutgoingMessageBufferSize ¶
func (x *Endpoint2Config) GetOverrideOutgoingMessageBufferSize() int32
func (*Endpoint2Config) ProtoMessage ¶
func (*Endpoint2Config) ProtoMessage()
func (*Endpoint2Config) ProtoReflect ¶
func (x *Endpoint2Config) ProtoReflect() protoreflect.Message
func (*Endpoint2Config) Reset ¶
func (x *Endpoint2Config) Reset()
func (*Endpoint2Config) String ¶
func (x *Endpoint2Config) String() string
type Endpoint2ProxyClient ¶
type Endpoint2ProxyClient interface {
// Connect manages the lifetime of a single BinaryNetworkEndpoint2. The first
// message must be NewEndpoint2Request; afterwards the stream carries
// SendTo/Broadcast up and received messages down.
Connect(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[Endpoint2ClientRequest, Endpoint2ServerMessage], error)
}
Endpoint2ProxyClient is the client API for Endpoint2Proxy service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Endpoint2Proxy exposes libocr's OCR3.1 BinaryNetworkEndpoint2Factory over the network. It shares the same underlying rage peer as the other proxy services.
func NewEndpoint2ProxyClient ¶
func NewEndpoint2ProxyClient(cc grpc.ClientConnInterface) Endpoint2ProxyClient
type Endpoint2ProxyServer ¶
type Endpoint2ProxyServer interface {
// Connect manages the lifetime of a single BinaryNetworkEndpoint2. The first
// message must be NewEndpoint2Request; afterwards the stream carries
// SendTo/Broadcast up and received messages down.
Connect(grpc.BidiStreamingServer[Endpoint2ClientRequest, Endpoint2ServerMessage]) error
// contains filtered or unexported methods
}
Endpoint2ProxyServer is the server API for Endpoint2Proxy service. All implementations must embed UnimplementedEndpoint2ProxyServer for forward compatibility.
Endpoint2Proxy exposes libocr's OCR3.1 BinaryNetworkEndpoint2Factory over the network. It shares the same underlying rage peer as the other proxy services.
type Endpoint2Proxy_ConnectClient ¶
type Endpoint2Proxy_ConnectClient = grpc.BidiStreamingClient[Endpoint2ClientRequest, Endpoint2ServerMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Endpoint2Proxy_ConnectServer ¶
type Endpoint2Proxy_ConnectServer = grpc.BidiStreamingServer[Endpoint2ClientRequest, Endpoint2ServerMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Endpoint2Send ¶
type Endpoint2Send struct {
ToOracleId uint32 `protobuf:"varint,1,opt,name=to_oracle_id,json=toOracleId,proto3" json:"to_oracle_id,omitempty"`
Msg *OutboundMessage2 `protobuf:"bytes,2,opt,name=msg,proto3" json:"msg,omitempty"`
// contains filtered or unexported fields
}
func (*Endpoint2Send) Descriptor
deprecated
func (*Endpoint2Send) Descriptor() ([]byte, []int)
Deprecated: Use Endpoint2Send.ProtoReflect.Descriptor instead.
func (*Endpoint2Send) GetMsg ¶
func (x *Endpoint2Send) GetMsg() *OutboundMessage2
func (*Endpoint2Send) GetToOracleId ¶
func (x *Endpoint2Send) GetToOracleId() uint32
func (*Endpoint2Send) ProtoMessage ¶
func (*Endpoint2Send) ProtoMessage()
func (*Endpoint2Send) ProtoReflect ¶
func (x *Endpoint2Send) ProtoReflect() protoreflect.Message
func (*Endpoint2Send) Reset ¶
func (x *Endpoint2Send) Reset()
func (*Endpoint2Send) String ¶
func (x *Endpoint2Send) String() string
type Endpoint2ServerMessage ¶
type Endpoint2ServerMessage struct {
Sender uint32 `protobuf:"varint,1,opt,name=sender,proto3" json:"sender,omitempty"`
Payload []byte `protobuf:"bytes,2,opt,name=payload,proto3" json:"payload,omitempty"`
Priority uint32 `protobuf:"varint,3,opt,name=priority,proto3" json:"priority,omitempty"` // raw ocr2types.BinaryMessageOutboundPriority value
// Types that are valid to be assigned to Kind:
//
// *Endpoint2ServerMessage_Plain
// *Endpoint2ServerMessage_Request
// *Endpoint2ServerMessage_Response
Kind isEndpoint2ServerMessage_Kind `protobuf_oneof:"kind"`
// contains filtered or unexported fields
}
Endpoint2ServerMessage mirrors ocr2types.InboundBinaryMessageWithSender.
func (*Endpoint2ServerMessage) Descriptor
deprecated
func (*Endpoint2ServerMessage) Descriptor() ([]byte, []int)
Deprecated: Use Endpoint2ServerMessage.ProtoReflect.Descriptor instead.
func (*Endpoint2ServerMessage) GetKind ¶
func (x *Endpoint2ServerMessage) GetKind() isEndpoint2ServerMessage_Kind
func (*Endpoint2ServerMessage) GetPayload ¶
func (x *Endpoint2ServerMessage) GetPayload() []byte
func (*Endpoint2ServerMessage) GetPlain ¶
func (x *Endpoint2ServerMessage) GetPlain() *InboundPlain2
func (*Endpoint2ServerMessage) GetPriority ¶
func (x *Endpoint2ServerMessage) GetPriority() uint32
func (*Endpoint2ServerMessage) GetRequest ¶
func (x *Endpoint2ServerMessage) GetRequest() *InboundRequest2
func (*Endpoint2ServerMessage) GetResponse ¶
func (x *Endpoint2ServerMessage) GetResponse() *InboundResponse2
func (*Endpoint2ServerMessage) GetSender ¶
func (x *Endpoint2ServerMessage) GetSender() uint32
func (*Endpoint2ServerMessage) ProtoMessage ¶
func (*Endpoint2ServerMessage) ProtoMessage()
func (*Endpoint2ServerMessage) ProtoReflect ¶
func (x *Endpoint2ServerMessage) ProtoReflect() protoreflect.Message
func (*Endpoint2ServerMessage) Reset ¶
func (x *Endpoint2ServerMessage) Reset()
func (*Endpoint2ServerMessage) String ¶
func (x *Endpoint2ServerMessage) String() string
type Endpoint2ServerMessage_Plain ¶
type Endpoint2ServerMessage_Plain struct {
Plain *InboundPlain2 `protobuf:"bytes,4,opt,name=plain,proto3,oneof"`
}
type Endpoint2ServerMessage_Request ¶
type Endpoint2ServerMessage_Request struct {
Request *InboundRequest2 `protobuf:"bytes,5,opt,name=request,proto3,oneof"`
}
type Endpoint2ServerMessage_Response ¶
type Endpoint2ServerMessage_Response struct {
Response *InboundResponse2 `protobuf:"bytes,6,opt,name=response,proto3,oneof"`
}
type InboundPlain2 ¶
type InboundPlain2 struct {
// contains filtered or unexported fields
}
func (*InboundPlain2) Descriptor
deprecated
func (*InboundPlain2) Descriptor() ([]byte, []int)
Deprecated: Use InboundPlain2.ProtoReflect.Descriptor instead.
func (*InboundPlain2) ProtoMessage ¶
func (*InboundPlain2) ProtoMessage()
func (*InboundPlain2) ProtoReflect ¶
func (x *InboundPlain2) ProtoReflect() protoreflect.Message
func (*InboundPlain2) Reset ¶
func (x *InboundPlain2) Reset()
func (*InboundPlain2) String ¶
func (x *InboundPlain2) String() string
type InboundRequest2 ¶
type InboundRequest2 struct {
RequestId uint64 `protobuf:"varint,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
func (*InboundRequest2) Descriptor
deprecated
func (*InboundRequest2) Descriptor() ([]byte, []int)
Deprecated: Use InboundRequest2.ProtoReflect.Descriptor instead.
func (*InboundRequest2) GetRequestId ¶
func (x *InboundRequest2) GetRequestId() uint64
func (*InboundRequest2) ProtoMessage ¶
func (*InboundRequest2) ProtoMessage()
func (*InboundRequest2) ProtoReflect ¶
func (x *InboundRequest2) ProtoReflect() protoreflect.Message
func (*InboundRequest2) Reset ¶
func (x *InboundRequest2) Reset()
func (*InboundRequest2) String ¶
func (x *InboundRequest2) String() string
type InboundResponse2 ¶
type InboundResponse2 struct {
// contains filtered or unexported fields
}
func (*InboundResponse2) Descriptor
deprecated
func (*InboundResponse2) Descriptor() ([]byte, []int)
Deprecated: Use InboundResponse2.ProtoReflect.Descriptor instead.
func (*InboundResponse2) ProtoMessage ¶
func (*InboundResponse2) ProtoMessage()
func (*InboundResponse2) ProtoReflect ¶
func (x *InboundResponse2) ProtoReflect() protoreflect.Message
func (*InboundResponse2) Reset ¶
func (x *InboundResponse2) Reset()
func (*InboundResponse2) String ¶
func (x *InboundResponse2) String() string
type NewEndpoint2Request ¶
type NewEndpoint2Request struct {
ConfigDigest []byte `protobuf:"bytes,1,opt,name=config_digest,json=configDigest,proto3" json:"config_digest,omitempty"`
PeerIds []string `protobuf:"bytes,2,rep,name=peer_ids,json=peerIds,proto3" json:"peer_ids,omitempty"`
V2Bootstrappers []*BootstrapperLocator `protobuf:"bytes,3,rep,name=v2_bootstrappers,json=v2Bootstrappers,proto3" json:"v2_bootstrappers,omitempty"`
DefaultPriorityConfig *Endpoint2Config `` /* 126-byte string literal not displayed */
LowPriorityConfig *Endpoint2Config `protobuf:"bytes,5,opt,name=low_priority_config,json=lowPriorityConfig,proto3" json:"low_priority_config,omitempty"`
// contains filtered or unexported fields
}
func (*NewEndpoint2Request) Descriptor
deprecated
func (*NewEndpoint2Request) Descriptor() ([]byte, []int)
Deprecated: Use NewEndpoint2Request.ProtoReflect.Descriptor instead.
func (*NewEndpoint2Request) GetConfigDigest ¶
func (x *NewEndpoint2Request) GetConfigDigest() []byte
func (*NewEndpoint2Request) GetDefaultPriorityConfig ¶
func (x *NewEndpoint2Request) GetDefaultPriorityConfig() *Endpoint2Config
func (*NewEndpoint2Request) GetLowPriorityConfig ¶
func (x *NewEndpoint2Request) GetLowPriorityConfig() *Endpoint2Config
func (*NewEndpoint2Request) GetPeerIds ¶
func (x *NewEndpoint2Request) GetPeerIds() []string
func (*NewEndpoint2Request) GetV2Bootstrappers ¶
func (x *NewEndpoint2Request) GetV2Bootstrappers() []*BootstrapperLocator
func (*NewEndpoint2Request) ProtoMessage ¶
func (*NewEndpoint2Request) ProtoMessage()
func (*NewEndpoint2Request) ProtoReflect ¶
func (x *NewEndpoint2Request) ProtoReflect() protoreflect.Message
func (*NewEndpoint2Request) Reset ¶
func (x *NewEndpoint2Request) Reset()
func (*NewEndpoint2Request) String ¶
func (x *NewEndpoint2Request) String() string
type NewEndpointRequest ¶
type NewEndpointRequest struct {
ConfigDigest []byte `protobuf:"bytes,1,opt,name=config_digest,json=configDigest,proto3" json:"config_digest,omitempty"`
PeerIds []string `protobuf:"bytes,2,rep,name=peer_ids,json=peerIds,proto3" json:"peer_ids,omitempty"`
V2Bootstrappers []*BootstrapperLocator `protobuf:"bytes,3,rep,name=v2_bootstrappers,json=v2Bootstrappers,proto3" json:"v2_bootstrappers,omitempty"`
FailureThreshold int32 `protobuf:"varint,4,opt,name=failure_threshold,json=failureThreshold,proto3" json:"failure_threshold,omitempty"`
Limits *BinaryNetworkEndpointLimits `protobuf:"bytes,5,opt,name=limits,proto3" json:"limits,omitempty"`
// contains filtered or unexported fields
}
func (*NewEndpointRequest) Descriptor
deprecated
func (*NewEndpointRequest) Descriptor() ([]byte, []int)
Deprecated: Use NewEndpointRequest.ProtoReflect.Descriptor instead.
func (*NewEndpointRequest) GetConfigDigest ¶
func (x *NewEndpointRequest) GetConfigDigest() []byte
func (*NewEndpointRequest) GetFailureThreshold ¶
func (x *NewEndpointRequest) GetFailureThreshold() int32
func (*NewEndpointRequest) GetLimits ¶
func (x *NewEndpointRequest) GetLimits() *BinaryNetworkEndpointLimits
func (*NewEndpointRequest) GetPeerIds ¶
func (x *NewEndpointRequest) GetPeerIds() []string
func (*NewEndpointRequest) GetV2Bootstrappers ¶
func (x *NewEndpointRequest) GetV2Bootstrappers() []*BootstrapperLocator
func (*NewEndpointRequest) ProtoMessage ¶
func (*NewEndpointRequest) ProtoMessage()
func (*NewEndpointRequest) ProtoReflect ¶
func (x *NewEndpointRequest) ProtoReflect() protoreflect.Message
func (*NewEndpointRequest) Reset ¶
func (x *NewEndpointRequest) Reset()
func (*NewEndpointRequest) String ¶
func (x *NewEndpointRequest) String() string
type OutboundMessage2 ¶
type OutboundMessage2 struct {
Payload []byte `protobuf:"bytes,1,opt,name=payload,proto3" json:"payload,omitempty"`
Priority uint32 `protobuf:"varint,2,opt,name=priority,proto3" json:"priority,omitempty"` // raw ocr2types.BinaryMessageOutboundPriority value
// Types that are valid to be assigned to Kind:
//
// *OutboundMessage2_Plain
// *OutboundMessage2_Request
// *OutboundMessage2_Response
Kind isOutboundMessage2_Kind `protobuf_oneof:"kind"`
// contains filtered or unexported fields
}
OutboundMessage2 mirrors ocr2types.OutboundBinaryMessage (plain/request/response).
func (*OutboundMessage2) Descriptor
deprecated
func (*OutboundMessage2) Descriptor() ([]byte, []int)
Deprecated: Use OutboundMessage2.ProtoReflect.Descriptor instead.
func (*OutboundMessage2) GetKind ¶
func (x *OutboundMessage2) GetKind() isOutboundMessage2_Kind
func (*OutboundMessage2) GetPayload ¶
func (x *OutboundMessage2) GetPayload() []byte
func (*OutboundMessage2) GetPlain ¶
func (x *OutboundMessage2) GetPlain() *OutboundPlain2
func (*OutboundMessage2) GetPriority ¶
func (x *OutboundMessage2) GetPriority() uint32
func (*OutboundMessage2) GetRequest ¶
func (x *OutboundMessage2) GetRequest() *OutboundRequest2
func (*OutboundMessage2) GetResponse ¶
func (x *OutboundMessage2) GetResponse() *OutboundResponse2
func (*OutboundMessage2) ProtoMessage ¶
func (*OutboundMessage2) ProtoMessage()
func (*OutboundMessage2) ProtoReflect ¶
func (x *OutboundMessage2) ProtoReflect() protoreflect.Message
func (*OutboundMessage2) Reset ¶
func (x *OutboundMessage2) Reset()
func (*OutboundMessage2) String ¶
func (x *OutboundMessage2) String() string
type OutboundMessage2_Plain ¶
type OutboundMessage2_Plain struct {
Plain *OutboundPlain2 `protobuf:"bytes,3,opt,name=plain,proto3,oneof"`
}
type OutboundMessage2_Request ¶
type OutboundMessage2_Request struct {
Request *OutboundRequest2 `protobuf:"bytes,4,opt,name=request,proto3,oneof"`
}
type OutboundMessage2_Response ¶
type OutboundMessage2_Response struct {
Response *OutboundResponse2 `protobuf:"bytes,5,opt,name=response,proto3,oneof"`
}
type OutboundPlain2 ¶
type OutboundPlain2 struct {
// contains filtered or unexported fields
}
func (*OutboundPlain2) Descriptor
deprecated
func (*OutboundPlain2) Descriptor() ([]byte, []int)
Deprecated: Use OutboundPlain2.ProtoReflect.Descriptor instead.
func (*OutboundPlain2) ProtoMessage ¶
func (*OutboundPlain2) ProtoMessage()
func (*OutboundPlain2) ProtoReflect ¶
func (x *OutboundPlain2) ProtoReflect() protoreflect.Message
func (*OutboundPlain2) Reset ¶
func (x *OutboundPlain2) Reset()
func (*OutboundPlain2) String ¶
func (x *OutboundPlain2) String() string
type OutboundRequest2 ¶
type OutboundRequest2 struct {
// SingleUseSizedLimitedResponsePolicy fields.
PolicyMaxSize int64 `protobuf:"varint,1,opt,name=policy_max_size,json=policyMaxSize,proto3" json:"policy_max_size,omitempty"`
PolicyExpiryUnixMs int64 `protobuf:"varint,2,opt,name=policy_expiry_unix_ms,json=policyExpiryUnixMs,proto3" json:"policy_expiry_unix_ms,omitempty"`
// contains filtered or unexported fields
}
func (*OutboundRequest2) Descriptor
deprecated
func (*OutboundRequest2) Descriptor() ([]byte, []int)
Deprecated: Use OutboundRequest2.ProtoReflect.Descriptor instead.
func (*OutboundRequest2) GetPolicyExpiryUnixMs ¶
func (x *OutboundRequest2) GetPolicyExpiryUnixMs() int64
func (*OutboundRequest2) GetPolicyMaxSize ¶
func (x *OutboundRequest2) GetPolicyMaxSize() int64
func (*OutboundRequest2) ProtoMessage ¶
func (*OutboundRequest2) ProtoMessage()
func (*OutboundRequest2) ProtoReflect ¶
func (x *OutboundRequest2) ProtoReflect() protoreflect.Message
func (*OutboundRequest2) Reset ¶
func (x *OutboundRequest2) Reset()
func (*OutboundRequest2) String ¶
func (x *OutboundRequest2) String() string
type OutboundResponse2 ¶
type OutboundResponse2 struct {
// Refers to the request_id of the InboundRequest2 being responded to; the
// server holds the real libocr RequestHandle keyed by this id.
RequestId uint64 `protobuf:"varint,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
func (*OutboundResponse2) Descriptor
deprecated
func (*OutboundResponse2) Descriptor() ([]byte, []int)
Deprecated: Use OutboundResponse2.ProtoReflect.Descriptor instead.
func (*OutboundResponse2) GetRequestId ¶
func (x *OutboundResponse2) GetRequestId() uint64
func (*OutboundResponse2) ProtoMessage ¶
func (*OutboundResponse2) ProtoMessage()
func (*OutboundResponse2) ProtoReflect ¶
func (x *OutboundResponse2) ProtoReflect() protoreflect.Message
func (*OutboundResponse2) Reset ¶
func (x *OutboundResponse2) Reset()
func (*OutboundResponse2) String ¶
func (x *OutboundResponse2) String() string
type ProxyEndpoint ¶
type ProxyEndpoint struct {
// contains filtered or unexported fields
}
func (*ProxyEndpoint) Broadcast ¶
func (e *ProxyEndpoint) Broadcast(msg []byte)
func (*ProxyEndpoint) Close ¶
func (e *ProxyEndpoint) Close() error
func (*ProxyEndpoint) Receive ¶
func (e *ProxyEndpoint) Receive() <-chan commontypes.BinaryMessageWithSender
func (*ProxyEndpoint) SendTo ¶
func (e *ProxyEndpoint) SendTo(msg []byte, to commontypes.OracleID)
func (*ProxyEndpoint) Start ¶
func (e *ProxyEndpoint) Start() error
type ProxyEndpoint2Factory ¶
type ProxyEndpoint2Factory struct {
// contains filtered or unexported fields
}
ProxyEndpoint2Factory is an ocr2types.BinaryNetworkEndpoint2Factory (OCR3.1) that delegates to a remote Endpoint2Proxy server.
func (*ProxyEndpoint2Factory) Close ¶
func (f *ProxyEndpoint2Factory) Close() error
func (*ProxyEndpoint2Factory) NewEndpoint ¶
func (f *ProxyEndpoint2Factory) NewEndpoint( cd ocr2types.ConfigDigest, peerIDs []string, v2bootstrappers []commontypes.BootstrapperLocator, defaultPriorityConfig ocr2types.BinaryNetworkEndpoint2Config, lowPriorityConfig ocr2types.BinaryNetworkEndpoint2Config, ) (ocr2types.BinaryNetworkEndpoint2, error)
func (*ProxyEndpoint2Factory) PeerID ¶
func (f *ProxyEndpoint2Factory) PeerID() string
type ProxyEndpointFactory ¶
type ProxyEndpointFactory struct {
// contains filtered or unexported fields
}
func (*ProxyEndpointFactory) Close ¶
func (f *ProxyEndpointFactory) Close() error
func (*ProxyEndpointFactory) NewEndpoint ¶
func (f *ProxyEndpointFactory) NewEndpoint( cd types.ConfigDigest, peerIDs []string, v2bootstrappers []commontypes.BootstrapperLocator, failureThreshold int, limits types.BinaryNetworkEndpointLimits, ) (commontypes.BinaryNetworkEndpoint, error)
func (*ProxyEndpointFactory) PeerID ¶
func (f *ProxyEndpointFactory) PeerID() string
type SendToRequest ¶
type SendToRequest struct {
Payload []byte `protobuf:"bytes,2,opt,name=payload,proto3" json:"payload,omitempty"`
ToOracleId uint32 `protobuf:"varint,3,opt,name=to_oracle_id,json=toOracleId,proto3" json:"to_oracle_id,omitempty"`
// contains filtered or unexported fields
}
func (*SendToRequest) Descriptor
deprecated
func (*SendToRequest) Descriptor() ([]byte, []int)
Deprecated: Use SendToRequest.ProtoReflect.Descriptor instead.
func (*SendToRequest) GetPayload ¶
func (x *SendToRequest) GetPayload() []byte
func (*SendToRequest) GetToOracleId ¶
func (x *SendToRequest) GetToOracleId() uint32
func (*SendToRequest) ProtoMessage ¶
func (*SendToRequest) ProtoMessage()
func (*SendToRequest) ProtoReflect ¶
func (x *SendToRequest) ProtoReflect() protoreflect.Message
func (*SendToRequest) Reset ¶
func (x *SendToRequest) Reset()
func (*SendToRequest) String ¶
func (x *SendToRequest) String() string
type UnimplementedBinaryNetworkEndpointProxyServer ¶
type UnimplementedBinaryNetworkEndpointProxyServer struct{}
UnimplementedBinaryNetworkEndpointProxyServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
type UnimplementedEndpoint2ProxyServer ¶
type UnimplementedEndpoint2ProxyServer struct{}
UnimplementedEndpoint2ProxyServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
type UnsafeBinaryNetworkEndpointProxyServer ¶
type UnsafeBinaryNetworkEndpointProxyServer interface {
// contains filtered or unexported methods
}
UnsafeBinaryNetworkEndpointProxyServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BinaryNetworkEndpointProxyServer will result in compilation errors.
type UnsafeEndpoint2ProxyServer ¶
type UnsafeEndpoint2ProxyServer interface {
// contains filtered or unexported methods
}
UnsafeEndpoint2ProxyServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to Endpoint2ProxyServer will result in compilation errors.